@@ -1,7 +1,8 @@
 from abc import ABC, abstractmethod
 from typing import List
 
-from .session_items import SessionComment, SessionRequestResponse, SessionSection
+from .session_items import (SessionComment, SessionRequestResponse,
+                            SessionSection)
 
 
 class SessionExporter(ABC):
