@@ -1,7 +1,7 @@
 import inspect
 from typing import Any, Dict, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, ConfigDict
 
 
 class NamedModel(BaseModel):
@@ -11,9 +11,11 @@ class NamedModel(BaseModel):
 class BaseResource(BaseModel):
     id: int
 
+    model_config = ConfigDict(extra="allow")
+
     @property
     def summary(self):
-        return summary(self)
+        return summary(self, True)
 
 
 class WithDescription(BaseModel):
@@ -21,8 +23,8 @@ class WithDescription(BaseModel):
 
 
 class PropertyMixin:
-    def get_all_fields_and_properties(self) -> Dict[str, Any]:
-        all_data = self.dict()
+    def get_all_fields_and_properties(self: BaseModel) -> Dict[str, Any]:
+        all_data = self.model_dump()
 
         for name, attribute in inspect.getmembers(self.__class__):
             if isinstance(attribute, property):
@@ -38,4 +40,4 @@ def summary(model: BaseModel, with_class=False):
     if hasattr(model, "id"):
         id_parts.append(str(model.id))
 
-    return "[{}] {}".format(".".join(id_parts), getattr(model, "name", ""))
+    return "({}) {}".format(".".join(id_parts), getattr(model, "name", ""))
